# pyIcePAP

pyIcePAP is a python module to configure, control and monitor IcePAP based systems.

## Documentation

The project documentation can be found [here](https://alba-synchrotron.github.io/pyIcePAP-doc) or you can build it by executing:

    python setup.py build_sphinx

This documentation has been created by [sphinx](http://www.sphinx-doc.org/en/stable/).

## Tests

You can run tests simply with:

    python setup.py test



## Contribute

You can find how to contribute to this project on CONTRIBUTING.md file.
